## Summary

<!-- What does this PR do and why? -->

## Changes

-

## Checklist

- [ ] Tests pass (`make ci`)
- [ ] New tests added for new functionality
- [ ] `uv run ruff check src/ tests/` clean
- [ ] CHANGELOG.md updated (if user-facing change)
- [ ] Documentation updated (if applicable)
